@@ -244,8 +244,8 @@ class Strategy:
 
         if not signal.empty:
             # 最后一期持仓
-            date = signal.iloc[-1].name
-            hold_last = signal.iloc[-1].to_frame('weight').dropna()
+            date = signal_all.iloc[-1].name
+            hold_last = signal_all.iloc[-1].to_frame('weight').dropna()
             hold_last.index.name = 'stockid'
             hold_last.reset_index(inplace=True)
             hold_last.sort_values('weight', ascending=False, inplace=True)
